Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(86)

Unified Diff: build/config/mac/sdk_info.py

Issue 1877523002: Mac/iOS/GN: Generate Info.plist files for Mac apps and frameworks with gn. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Delete version information to be populated elsewhere, fix assert string. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/config/mac/rules.gni ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/config/mac/sdk_info.py
diff --git a/build/config/ios/ios_sdk.py b/build/config/mac/sdk_info.py
similarity index 85%
rename from build/config/ios/ios_sdk.py
rename to build/config/mac/sdk_info.py
index a94614aa8200cf36003caec9d910a02823690797..ad4ad9e98975d8b7d38c60696ed9d7fa5305b196 100644
--- a/build/config/ios/ios_sdk.py
+++ b/build/config/mac/sdk_info.py
@@ -7,8 +7,8 @@ import subprocess
import sys
# This script prints information about the build system, the operating
# system and the iOS SDK (depending on the platform "iphonesimulator"
# or "iphoneos" generally).
#
# In the GYP build, this is done inside GYP itself based on the SDKROOT
# variable.
@@ -37,15 +37,15 @@ def FillSDKPathAndVersion(settings, platform):
"""Fills the SDK path and version for |platform| into |settings|."""
lines = subprocess.check_output(['xcodebuild', '-version', '-sdk',
platform, 'Path', 'SDKVersion', 'ProductBuildVersion']).splitlines()
- settings['ios_sdk_path'] = lines[0]
- settings['ios_sdk_version'] = lines[1]
- settings['ios_sdk_build'] = lines[2]
+ settings['sdk_path'] = lines[0]
+ settings['sdk_version'] = lines[1]
+ settings['sdk_build'] = lines[2]
if __name__ == '__main__':
if len(sys.argv) != 2:
sys.stderr.write(
- 'usage: %s [iphoneos|iphonesimulator]\n' %
+ 'usage: %s [iphoneos|iphonesimulator|macosx]\n' %
os.path.basename(sys.argv[0]))
sys.exit(1)
« no previous file with comments | « build/config/mac/rules.gni ('k') | no next file » | no next file with comments »
@@ -7,8 +7,8 @@ import subprocess
import sys
# This script prints information about the build system, the operating
-# system and the iOS SDK (depending on the platform "iphonesimulator"
-# or "iphoneos" generally).
+# system and the iOS or Mac SDK (depending on the platform "iphonesimulator",
+# "iphoneos" or "macosx" generally).
#
# In the GYP build, this is done inside GYP itself based on the SDKROOT

Powered by Google App Engine
This is Rietveld 408576698